@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.7.") or
-    raise "ruby lib version (2.7.4) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.7.5) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.7/riscv64-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "7"
-  CONFIG["TEENY"] = "4"
-  CONFIG["PATCHLEVEL"] = "191"
-  CONFIG["INSTALL"] = '/local/pobj/ruby-2.7.4/bin/install -c'
+  CONFIG["TEENY"] = "5"
+  CONFIG["PATCHLEVEL"] = "203"
+  CONFIG["INSTALL"] = '/local/pobj/ruby-2.7.5/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)27"
@@ -95,7 +95,7 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3"
   CONFIG["NULLCMD"] = ":"
@@ -149,9 +149,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/local/pobj/ruby-2.7.4/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/local/pobj/ruby-2.7.4/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/local/pobj/ruby-2.7.4/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/local/pobj/ruby-2.7.5/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/local/pobj/ruby-2.7.5/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/local/pobj/ruby-2.7.5/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -165,7 +165,7 @@ module RbConfig
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 11.1.0\nTarget: riscv64-unknown-openbsd7.0\nThread model: posix\nInstalledDir: /usr/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 13.0.0\nTarget: riscv64-unknown-openbsd7.1\nThread model: posix\nInstalledDir: /usr/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "/usr/bin/cc"
   CONFIG["CSRCFLAG"] = ""
@@ -185,21 +185,21 @@ module RbConfig
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -fstack-protector-strong -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd7.0"
+  CONFIG["target_os"] = "openbsd7.1"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "riscv64"
-  CONFIG["target"] = "riscv64-unknown-openbsd7.0"
-  CONFIG["host_os"] = "openbsd7.0"
+  CONFIG["target"] = "riscv64-unknown-openbsd7.1"
+  CONFIG["host_os"] = "openbsd7.1"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "riscv64"
-  CONFIG["host"] = "riscv64-unknown-openbsd7.0"
+  CONFIG["host"] = "riscv64-unknown-openbsd7.1"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd7.0"
+  CONFIG["build_os"] = "openbsd7.1"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "riscv64"
-  CONFIG["build"] = "riscv64-unknown-openbsd7.0"
+  CONFIG["build"] = "riscv64-unknown-openbsd7.1"
   CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
   CONFIG["HAVE_GIT"] = "no"
