@@ -194,62 +194,21 @@ You can use `i` command instead of `install`.
 
     req = Gem::Requirement.create(version)
 
-    if options[:ignore_dependencies]
-      install_gem_without_dependencies name, req
-    else
-      inst = Gem::DependencyInstaller.new options
-      request_set = inst.resolve_dependencies name, req
-
-      if options[:explain]
-        puts "Gems to install:"
-
-        request_set.sorted_requests.each do |s|
-          puts "  #{s.full_name}"
-        end
-
-        return
-      else
-        @installed_specs.concat request_set.install options
-      end
-
-      show_install_errors inst.errors
-    end
-  end
-
-  def install_gem_without_dependencies(name, req) # :nodoc:
-    gem = nil
-
-    if local?
-      if name =~ /\.gem$/ and File.file? name
-        source = Gem::Source::SpecificFile.new name
-        spec = source.spec
-      else
-        source = Gem::Source::Local.new
-        spec = source.find_gem name, req
-      end
-      gem = source.download spec if spec
-    end
-
-    if remote? and not gem
-      dependency = Gem::Dependency.new name, req
-      dependency.prerelease = options[:prerelease]
-
-      fetcher = Gem::RemoteFetcher.fetcher
-      gem = fetcher.download_to_cache dependency
-    end
-
-    inst = Gem::Installer.at gem, options
-    inst.install
-
-    require 'rubygems/dependency_installer'
     dinst = Gem::DependencyInstaller.new options
-    dinst.installed_gems.replace [inst.spec]
 
-    Gem.done_installing_hooks.each do |hook|
-      hook.call dinst, [inst.spec]
-    end unless Gem.done_installing_hooks.empty?
+    request_set = dinst.resolve_dependencies name, req
 
-    @installed_specs.push(inst.spec)
+    if options[:explain]
+      say "Gems to install:"
+
+      request_set.sorted_requests.each do |activation_request|
+        say "  #{activation_request.full_name}"
+      end
+    else
+      @installed_specs.concat request_set.install options
+    end
+
+    show_install_errors dinst.errors
   end
 
   def install_gems # :nodoc:
@@ -259,6 +218,7 @@ You can use `i` command instead of `install`.
       gem_version ||= options[:version]
       domain = options[:domain]
       domain = :local unless options[:suggest_alternate]
+      supress_suggestions = (domain == :local)
 
       begin
         install_gem gem_name, gem_version
@@ -266,11 +226,11 @@ You can use `i` command instead of `install`.
         alert_error "Error installing #{gem_name}:\n\t#{e.message}"
         exit_code |= 1
       rescue Gem::GemNotFoundException => e
-        show_lookup_failure e.name, e.version, e.errors, domain
+        show_lookup_failure e.name, e.version, e.errors, supress_suggestions
 
         exit_code |= 2
       rescue Gem::UnsatisfiableDependencyError => e
-        show_lookup_failure e.name, e.version, e.errors, domain,
+        show_lookup_failure e.name, e.version, e.errors, supress_suggestions,
                             "'#{gem_name}' (#{gem_version})"
 
         exit_code |= 2
